# i asked chatgpt to generate brainrot and this is what it gave... pls dont ask
quotes = [
    "Invest in {stock}? Fam, that’s more sus than Freddy Fazbear at 3 AM 💀💀💀.",
    "Bruh, if {stock} tanks, just know… I’m in sturdy mode with my diamond hands 🗿✨ #HoldTheLine.",
    "They say {stock} is ‘to the moon’ but blud, it’s giving Ohio energy frfr 😭💀.",
    "{stock} is up? Blud, that’s some sigma grindset vibes. Down? It’s Quandale Dingle levels of L ☠️💀.",
    "Buying {stock} is like saying ‘womp womp’ to financial sanity 💀💀. Good luck, fam.",
    "In {stock} we don’t trust… unless it’s giving Kai Cenat rizz levels 🌚🚀. Otherwise? Pure L energy.",
    "If {stock} goes up, I'm living my Patrick Bateman fantasy. If it tanks, I’m cooked like EDP445 in Ohio ☠️☠️.",
    "{stock} to the moon? Nah fam, we’re in the skibidi toilet 🚽 vibes with this one 💀.",
    "The way {stock} be moving… it’s straight up a Roblox obby for my portfolio. Those who know, know 💀☠️😭.",
    "Bruh, {stock} is either gon’ hit ‘prime looksmaxxing’ or it’s a one-way ticket to the shadow realm 🍷🗿.",
    "Investing in {stock} is just a sussy baka move 🗿💀, like, are you even sturdy?",
    "Bro’s going all-in on {stock} like it’s Ice Spice in Ambatukam mode 🍷😭. We gon’ need a miracle.",
    "Just bought {stock} because I saw it trending on TikTok. It’s either L gyatt or W edge… let’s see 😭💀.",
    "{stock} stock is so cooked it’s practically Adin Ross at the skibidi toilet 💀. Sussy vibes only.",
    "They say ‘buy low, sell high,’ but like… {stock} out here playing full-on sus games 😭😭.",
    "{stock}: Not sure if it’s prime looksmaxxed or if it’s cooked harder than Quandale Dingle’s rizz ☠️.",
    "Lowkey, {stock} just pulled a Blue Tie Kid on my portfolio… that ain’t sturdy 💀💀.",
    "{stock} stock: for the true gooners and sigma grinders 💀. Hold if you dare, blud.",
    "{stock} is up and down like Adin Ross at 3 AM… not sure if we’re in sturdy mode or cooked 🗿🍷.",
    "Bruh, investing in {stock} is like throwing bags at Kai Cenat’s Costco. Risky vibes only, fam 💀💀.",
    "{stock} is either gonna gyatt or bomboclat my portfolio. We’re costco guys… let’s get sturdy 🍷🗿."
]
